pub struct Device;Expand description
CUDA device.
Implementations
Sourceimpl Device
impl Device
Sourcepub async fn get() -> Result<DeviceId, Error>
pub async fn get() -> Result<DeviceId, Error>
Returns which device is currently being used by DeviceId.
Sourcepub async fn synchronize() -> Result<(), Error>
pub async fn synchronize() -> Result<(), Error>
Synchronize the current CUDA device.
Warning
Note that this operation will block all device operations, even from other processes while running. Use this operation sparingly.
Sourcepub async fn memory_info() -> Result<MemoryInfo, Error>
pub async fn memory_info() -> Result<MemoryInfo, Error>